@@ -211,7 +211,7 @@ install_deps() {
 	if [ x"$RHEL" = x8 ]; then
             yum -y install python2-devel
 	    llvm_version=$(yum list --showduplicates llvm-devel | grep "17.0" | grep llvm | awk '{print $2}' | head -n 1)
-	    yum -y install llvm-devel--${llvm_version}
+	    yum -y install llvm-devel-${llvm_version}
         else
             yum -y install python-devel llvm-devel
         fi
@@ -528,7 +528,7 @@ BRANCH="main"
 INSTALL=0
 RPM_RELEASE=1
 DEB_RELEASE=1
-GIT_REPO="https://github.com/Percona-Lab/percona_pg_telemetry.git"
+GIT_REPO="https://github.com/percona/percona_pg_telemetry.git"
 VERSION="1.0.0"
 PG_RELEASE=16
 PPG_REPO=ppg-16.2
